;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Schematic program tests.
;;;
;;; These tests requires CHICKEN Scheme.
;;;
;;; See this project's README for more information.
;;;
;;; Copyright (c) 2014-2018, Evan Hanson <evhan@foldling.org>
;;; See LICENSE for details.
;;;

(cond-expand
  (chicken
   (import (chicken format)
           (chicken process)
           (chicken file posix)
           (schematic process)
           (test)))
  (else
   (display "Tests require CHICKEN Scheme, skipping.\n")
   (exit 0)))

(define programs
  '("schematic-extract"
    "schematic-format"
    "schematic-markdown"
    "schematic-wiki"))

;; --version flag.
(for-each (lambda (bin)
            (test (format "~a (version)" bin)
                  (string->symbol version)
                  (with-input-from-pipe (format "../~a --version" bin) read)))
          programs)

;; Empty input.
(for-each (lambda (bin)
            (let*-values (((i o) (create-pipe))
                          ((_)   (file-close o))
                          ((pid) (process-fork
                                  (lambda ()
                                    (duplicate-fileno i fileno/stdin)
                                    (process-execute (format "../~a" bin)))))
                          ((_ _ status) (process-wait pid)))
              (test-assert (format "~a (no input)" bin)
                           (zero? status))))
          programs)
